@@ -28,7 +28,6 @@ from tqdm import tqdm
 
 from camel.agents import ChatAgent
 from camel.benchmarks.base import BaseBenchmark
-from camel.messages import BaseMessage
 
 logger = logging.getLogger(__name__)
 
@@ -309,13 +308,10 @@ class NexusBenchmark(BaseBenchmark):
         with open(self.save_to, "w") as f:
             for sample in tqdm(datas, desc="Running"):
                 prompt = construct_prompt(input=sample.input, tools=tools)
-                msg = BaseMessage.make_user_message(
-                    role_name="User", content=prompt
-                )
                 ground_truth_call = sample.output
                 try:
                     # Generate response
-                    response = agent.step(msg)
+                    response = agent.step(prompt)
                     agent_call = response.msgs[0].content
 
                     # Evaluate response
@@ -347,7 +343,10 @@ class NexusBenchmark(BaseBenchmark):
 
                 agent.reset()
 
-                f.write(json.dumps(self._results[-1], indent=2) + "\n")
+                json_str = json.dumps(
+                    self._results[-1], indent=2, ensure_ascii=False
+                )
+                f.write(json_str + "\n")
                 f.flush()
 
         total = len(self._results)
