@@ -12,10 +12,12 @@
 # limitations under the License.
 # ========= Copyright 2023-2024 @ CAMEL-AI.org. All Rights Reserved. =========
 
-from .cotdatagen import CoTDataGenerator
+from .cot_datagen import CoTDataGenerator
+from .self_improving_cot import SelfImprovingCoTPipeline
 from .self_instruct import SelfInstructPipeline
 
 __all__ = [
     "CoTDataGenerator",
     "SelfInstructPipeline",
+    "SelfImprovingCoTPipeline",
 ]
