@@ -15,9 +15,11 @@
 from .apify_reader import Apify
 from .base_io import File, create_file, create_file_from_raw_bytes
 from .chunkr_reader import ChunkrReader
+from .crawl4ai_reader import Crawl4AI
 from .firecrawl_reader import Firecrawl
 from .jina_url_reader import JinaURLReader
-from .panda_reader import PandaReader
+from .mineru_extractor import MinerU
+from .pandas_reader import PandasReader
 from .unstructured_io import UnstructuredIO
 
 __all__ = [
@@ -29,5 +31,7 @@ __all__ = [
     'Firecrawl',
     'Apify',
     'ChunkrReader',
-    'PandaReader',
+    'PandasReader',
+    'MinerU',
+    'Crawl4AI',
 ]
