@@ -15,7 +15,7 @@ import base64
 import io
 import re
 from dataclasses import dataclass
-from typing import Any, Dict, List, Literal, Optional, Tuple, Type, Union
+from typing import Any, Dict, List, Literal, Optional, Tuple, Union
 
 import numpy as np
 from PIL import Image
@@ -72,7 +72,7 @@ class BaseMessage:
     image_list: Optional[List[Image.Image]] = None
     image_detail: Literal["auto", "low", "high"] = "auto"
     video_detail: Literal["auto", "low", "high"] = "low"
-    parsed: Optional[Union[Type[BaseModel], dict]] = None
+    parsed: Optional[Union[BaseModel, dict]] = None
 
     @classmethod
     def make_user_message(
@@ -416,8 +416,8 @@ class BaseMessage:
         Returns:
             OpenAIUserMessage: The converted :obj:`OpenAIUserMessage` object.
         """
-        hybird_content: List[Any] = []
-        hybird_content.append(
+        hybrid_content: List[Any] = []
+        hybrid_content.append(
             {
                 "type": "text",
                 "text": self.content,
@@ -445,7 +445,7 @@ class BaseMessage:
                         "utf-8"
                     )
                 image_prefix = f"data:image/{image_type};base64,"
-                hybird_content.append(
+                hybrid_content.append(
                     {
                         "type": "image_url",
                         "image_url": {
@@ -504,12 +504,12 @@ class BaseMessage:
                     },
                 }
 
-                hybird_content.append(item)
+                hybrid_content.append(item)
 
-        if len(hybird_content) > 1:
+        if len(hybrid_content) > 1:
             return {
                 "role": "user",
-                "content": hybird_content,
+                "content": hybrid_content,
             }
         # This return just for str message
         else:
