@@ -11,8 +11,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ========= Copyright 2023-2024 @ CAMEL-AI.org. All Rights Reserved. =========
+from .aiml_model import AIMLModel
 from .anthropic_model import AnthropicModel
 from .azure_openai_model import AzureOpenAIModel
+from .base_audio_model import BaseAudioModel
 from .base_model import BaseModelBackend
 from .cohere_model import CohereModel
 from .deepseek_model import DeepSeekModel
@@ -24,25 +26,32 @@ from .litellm_model import LiteLLMModel
 from .mistral_model import MistralModel
 from .model_factory import ModelFactory
 from .model_manager import ModelManager, ModelProcessingError
+from .modelscope_model import ModelScopeModel
+from .moonshot_model import MoonshotModel
 from .nemotron_model import NemotronModel
 from .nvidia_model import NvidiaModel
 from .ollama_model import OllamaModel
 from .openai_audio_models import OpenAIAudioModels
 from .openai_compatible_model import OpenAICompatibleModel
 from .openai_model import OpenAIModel
+from .openrouter_model import OpenRouterModel
+from .ppio_model import PPIOModel
 from .qwen_model import QwenModel
 from .reka_model import RekaModel
 from .samba_model import SambaModel
 from .sglang_model import SGLangModel
+from .siliconflow_model import SiliconFlowModel
 from .stub_model import StubModel
 from .togetherai_model import TogetherAIModel
 from .vllm_model import VLLMModel
+from .volcano_model import VolcanoModel
 from .yi_model import YiModel
 from .zhipuai_model import ZhipuAIModel
 
 __all__ = [
     'BaseModelBackend',
     'OpenAIModel',
+    'OpenRouterModel',
     'AzureOpenAIModel',
     'AnthropicModel',
     'MistralModel',
@@ -64,10 +73,17 @@ __all__ = [
     'RekaModel',
     'SambaModel',
     'TogetherAIModel',
+    'PPIOModel',
     'YiModel',
     'QwenModel',
     'ModelProcessingError',
     'DeepSeekModel',
     'FishAudioModel',
     'InternLMModel',
+    'ModelScopeModel',
+    'MoonshotModel',
+    'AIMLModel',
+    'BaseAudioModel',
+    'SiliconFlowModel',
+    'VolcanoModel',
 ]
