@@ -21,6 +21,7 @@ from .base import (
 )
 from .milvus import MilvusStorage
 from .qdrant import QdrantStorage
+from .tidb import TiDBStorage
 
 __all__ = [
     'BaseVectorStorage',
@@ -28,6 +29,7 @@ __all__ = [
     'VectorDBQueryResult',
     'QdrantStorage',
     'MilvusStorage',
+    "TiDBStorage",
     'VectorRecord',
     'VectorDBStatus',
 ]
