@@ -17,6 +17,7 @@ from typing import List, Literal, Optional, Tuple, Union
 
 from camel.toolkits import FunctionTool
 from camel.toolkits.base import BaseToolkit
+from camel.utils import MCPServer, api_keys_required
 
 
 def _process_response(
@@ -55,6 +56,10 @@ def _process_response(
         raise ValueError(f"Invalid return_type: {return_type}")
 
 
+@api_keys_required(
+    [(None, "ASKNEWS_CLIENT_ID"), (None, "ASKNEWS_CLIENT_SECRET")]
+)
+@MCPServer()
 class AskNewsToolkit(BaseToolkit):
     r"""A class representing a toolkit for interacting with the AskNews API.
 
@@ -62,11 +67,16 @@ class AskNewsToolkit(BaseToolkit):
     based on user queries using the AskNews API.
     """
 
-    def __init__(self):
+    def __init__(
+        self,
+        timeout: Optional[float] = None,
+    ):
         r"""Initialize the AskNewsToolkit with API clients.The API keys and
         credentials are retrieved from environment variables.
         """
-        from asknews_sdk import AskNewsSDK
+        super().__init__(timeout=timeout)
+
+        from asknews_sdk import AskNewsSDK  # type: ignore[import-not-found]
 
         client_id = os.environ.get("ASKNEWS_CLIENT_ID")
         client_secret = os.environ.get("ASKNEWS_CLIENT_SECRET")
@@ -150,7 +160,7 @@ class AskNewsToolkit(BaseToolkit):
                 each update. (default: :obj:`10`)
 
         Returns:
-            Unio[dict, str]: A dictionary containing the stories and their
+            Union[dict, str]: A dictionary containing the stories and their
                 associated data, or error message if the process fails.
         """
         try:
@@ -444,7 +454,7 @@ class AsyncAskNewsToolkit(BaseToolkit):
                 each update. (default: :obj:`10`)
 
         Returns:
-            Unio[dict, str]: A dictionary containing the stories and their
+            Union[dict, str]: A dictionary containing the stories and their
                 associated data, or error message if the process fails.
         """
         try:
