@@ -12,14 +12,36 @@
 # limitations under the License.
 # ========= Copyright 2023-2024 @ CAMEL-AI.org. All Rights Reserved. =========
 
-from typing import List
+from typing import List, Optional
 
 from camel.toolkits import FunctionTool
-from camel.utils import AgentOpsMeta
+from camel.utils import AgentOpsMeta, with_timeout
 
 
 class BaseToolkit(metaclass=AgentOpsMeta):
-    r"""Base class for toolkits."""
+    r"""Base class for toolkits.
+
+    Args:
+        timeout (Optional[float]): The timeout for the toolkit.
+    """
+
+    from mcp.server import FastMCP
+
+    mcp: FastMCP
+    timeout: Optional[float] = None
+
+    def __init__(self, timeout: Optional[float] = None):
+        # check if timeout is a positive number
+        if timeout is not None and timeout <= 0:
+            raise ValueError("Timeout must be a positive number.")
+        self.timeout = timeout
+
+    # Add timeout to all callable methods in the toolkit
+    def __init_subclass__(cls, **kwargs):
+        super().__init_subclass__(**kwargs)
+        for attr_name, attr_value in cls.__dict__.items():
+            if callable(attr_value) and not attr_name.startswith("__"):
+                setattr(cls, attr_name, with_timeout(attr_value))
 
     def get_tools(self) -> List[FunctionTool]:
         r"""Returns a list of FunctionTool objects representing the
