@@ -11,12 +11,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ========= Copyright 2023-2024 @ CAMEL-AI.org. All Rights Reserved. =========
+import asyncio
+import functools
 import importlib
+import inspect
+import logging
 import os
 import platform
 import re
 import socket
 import subprocess
+import threading
 import time
 import zipfile
 from functools import wraps
@@ -47,6 +52,8 @@ from .constants import Constants
 
 F = TypeVar('F', bound=Callable[..., Any])
 
+logger = logging.getLogger(__name__)
+
 
 def print_text_animated(text, delay: float = 0.02, end: str = ""):
     r"""Prints the given text with an animated effect.
@@ -156,7 +163,7 @@ def get_task_list(task_response: str) -> List[str]:
 
 
 def check_server_running(server_url: str) -> bool:
-    r"""Check whether the port refered by the URL to the server
+    r"""Check whether the port referred by the URL to the server
     is open.
 
     Args:
@@ -302,10 +309,55 @@ def api_keys_required(
                 if not value or value.strip() == "":
                     missing_keys.append(env_var_name)
 
+            key_way = "the official website"
+            if env_var_name == 'ANTHROPIC_API_KEY':
+                key_way = (
+                    "https://docs.anthropic.com/zh-CN/api/getting-started"
+                )
+            elif env_var_name == 'AIML_API_KEY':
+                key_way = "https://aimlapi.com/"
+            elif env_var_name == 'COHERE_API_KEY':
+                key_way = "https://cohere.com/"
+            elif env_var_name == 'DEEPSEEK_API_KEY':
+                key_way = "https://www.deepseek.com/"
+            elif env_var_name == 'AZURE_OPENAI_API_KEY':
+                key_way = "https://portal.azure.com/"
+            elif env_var_name == 'OPENAI_API_KEY':
+                key_way = "https://platform.openai.com/docs/overview"
+            elif env_var_name == 'FISHAUDIO_API_KEY':
+                key_way = "https://fish.audio/"
+            elif env_var_name == 'GEMINI_API_KEY':
+                key_way = "https://gemini.google.com/"
+            elif env_var_name == 'INTERNLM_API_KEY':
+                key_way = "https://internlm-chat.intern-ai.org.cn/puyu/api/v1"
+            elif env_var_name == 'GROQ_API_KEY':
+                key_way = "https://api.groq.com/openai/v1"
+            elif env_var_name == 'MISTRAL_API_KEY':
+                key_way = "https://mistral.ai/"
+            elif env_var_name == 'MOONSHOT_API_KEY':
+                key_way = "https://api.moonshot.cn/v1"
+            elif env_var_name == 'NVIDIA_API_KEY':
+                key_way = "https://integrate.api.nvidia.com/"
+            elif env_var_name == 'OPENAI_COMPATIBILITY_API_KEY':
+                key_way = "https://platform.openai.com/docs/overview"
+            elif env_var_name == 'QWEN_API_KEY':
+                key_way = "https://tongyi.aliyun.com/"
+            elif env_var_name == 'REKA_API_KEY':
+                key_way = "https://docs.reka.ai/quick-start"
+            elif env_var_name == 'SAMBA_API_KEY':
+                key_way = "https://community.sambanova.ai/t/looking-for-api-key-and-url-for-sambanova/576"
+            elif env_var_name == 'TOGETHER_API_KEY':
+                key_way = "https://docs.together.ai/docs/quickstart"
+            elif env_var_name == 'YI_API_KEY':
+                key_way = "https://platform.lingyiwanwu.com/docs"
+            elif env_var_name == 'ZHIPUAI_API_KEY':
+                key_way = "https://www.zhipuai.cn/"
+
             if missing_keys:
                 raise ValueError(
                     "Missing or empty required API keys in "
-                    f"environment variables: {', '.join(missing_keys)}"
+                    f"environment variables: {', '.join(missing_keys)}.\n"
+                    f"You can obtain the API key from {key_way}"
                 )
             return func(*args, **kwargs)
 
@@ -620,33 +672,206 @@ def handle_http_error(response: requests.Response) -> str:
         return "HTTP Error"
 
 
-def retry_request(
-    func: Callable, retries: int = 3, delay: int = 1, *args: Any, **kwargs: Any
-) -> Any:
-    r"""Retries a function in case of any errors.
+def retry_on_error(
+    max_retries: int = 3, initial_delay: float = 1.0
+) -> Callable:
+    r"""Decorator to retry function calls on exception with exponential
+    backoff.
 
     Args:
-        func (Callable): The function to be retried.
-        retries (int): Number of retry attempts. (default: :obj:`3`)
-        delay (int): Delay between retries in seconds. (default: :obj:`1`)
-        *args: Arguments to pass to the function.
-        **kwargs: Keyword arguments to pass to the function.
+        max_retries (int): Maximum number of retry attempts
+        initial_delay (float): Initial delay between retries in seconds
 
     Returns:
-        Any: The result of the function call if successful.
-
-    Raises:
-        Exception: If all retry attempts fail.
+        Callable: Decorated function with retry logic
     """
-    for attempt in range(retries):
-        try:
-            return func(*args, **kwargs)
-        except Exception as e:
-            print(f"Attempt {attempt + 1}/{retries} failed: {e}")
-            if attempt < retries - 1:
-                time.sleep(delay)
-            else:
-                raise
+
+    def decorator(func: Callable) -> Callable:
+        @functools.wraps(func)
+        def wrapper(*args, **kwargs):
+            delay = initial_delay
+            last_exception = None
+
+            for attempt in range(max_retries + 1):
+                try:
+                    return func(*args, **kwargs)
+                except Exception as e:
+                    last_exception = e
+                    if attempt == max_retries:
+                        logger.error(
+                            f"Failed after {max_retries} retries: {e!s}"
+                        )
+                        raise
+
+                    logger.warning(
+                        f"Attempt {attempt + 1} failed: {e!s}. "
+                        f"Retrying in {delay:.1f}s..."
+                    )
+                    time.sleep(delay)
+                    delay *= 2  # Exponential backoff
+
+            raise last_exception
+
+        return wrapper
+
+    return decorator
+
+
+class BatchProcessor:
+    r"""Handles batch processing with dynamic sizing and error handling based
+    on system load.
+    """
+
+    def __init__(
+        self,
+        max_workers: Optional[int] = None,
+        initial_batch_size: Optional[int] = None,
+        monitoring_interval: float = 5.0,
+        cpu_threshold: float = 80.0,
+        memory_threshold: float = 85.0,
+    ):
+        r"""Initialize the BatchProcessor with dynamic worker allocation.
+
+        Args:
+            max_workers: Maximum number of workers. If None, will be
+                determined dynamically based on system resources.
+                (default: :obj:`None`)
+            initial_batch_size: Initial size of each batch. If `None`,
+                defaults to `10`. (default: :obj:`None`)
+            monitoring_interval: Interval in seconds between resource checks.
+                (default: :obj:`5.0`)
+            cpu_threshold: CPU usage percentage threshold for scaling down.
+                (default: :obj:`80.0`)
+            memory_threshold: Memory usage percentage threshold for scaling
+                down. (default: :obj:`85.0`)
+        """
+        import psutil
+
+        self.monitoring_interval = monitoring_interval
+        self.cpu_threshold = cpu_threshold
+        self.memory_threshold = memory_threshold
+        self.last_check_time = time.time()
+        self.psutil = psutil
+
+        # Initialize performance metrics
+        self.total_processed = 0
+        self.total_errors = 0
+        self.processing_times: List = []
+
+        if max_workers is None:
+            self.max_workers = self._calculate_optimal_workers()
+        else:
+            self.max_workers = max_workers
+
+        self.batch_size = (
+            10 if initial_batch_size is None else initial_batch_size
+        )
+        self.min_batch_size = 1
+        self.max_batch_size = 20
+        self.backoff_factor = 0.8
+        self.success_factor = 1.2
+
+        # Initial resource check
+        self._update_resource_metrics()
+
+    def _calculate_optimal_workers(self) -> int:
+        r"""Calculate optimal number of workers based on system resources."""
+        cpu_count = self.psutil.cpu_count()
+        cpu_percent = self.psutil.cpu_percent(interval=1)
+        memory = self.psutil.virtual_memory()
+
+        # Base number of workers on CPU count and current load
+        if cpu_percent > self.cpu_threshold:
+            workers = max(1, cpu_count // 4)
+        elif cpu_percent > 60:
+            workers = max(1, cpu_count // 2)
+        else:
+            workers = max(1, cpu_count - 1)
+
+        # Further reduce if memory is constrained
+        if memory.percent > self.memory_threshold:
+            workers = max(1, workers // 2)
+
+        return workers
+
+    def _update_resource_metrics(self) -> None:
+        r"""Update current resource usage metrics."""
+        self.current_cpu = self.psutil.cpu_percent()
+        self.current_memory = self.psutil.virtual_memory().percent
+        self.last_check_time = time.time()
+
+    def _should_check_resources(self) -> bool:
+        r"""Determine if it's time to check resource usage again."""
+        return time.time() - self.last_check_time >= self.monitoring_interval
+
+    def adjust_batch_size(
+        self, success: bool, processing_time: Optional[float] = None
+    ) -> None:
+        r"""Adjust batch size based on success/failure and system resources.
+
+        Args:
+            success (bool): Whether the last batch completed successfully
+            processing_time (Optional[float]): Time taken to process the last
+                batch. (default: :obj:`None`)
+        """
+        # Update metrics
+        self.total_processed += 1
+        if not success:
+            self.total_errors += 1
+        if processing_time is not None:
+            self.processing_times.append(processing_time)
+
+        # Check system resources if interval has elapsed
+        if self._should_check_resources():
+            self._update_resource_metrics()
+
+            # Adjust based on resource usage
+            if (
+                self.current_cpu > self.cpu_threshold
+                or self.current_memory > self.memory_threshold
+            ):
+                self.batch_size = max(
+                    int(self.batch_size * self.backoff_factor),
+                    self.min_batch_size,
+                )
+                self.max_workers = max(1, self.max_workers - 1)
+                return
+
+        # Adjust based on success/failure
+        if success:
+            self.batch_size = min(
+                int(self.batch_size * self.success_factor), self.max_batch_size
+            )
+        else:
+            self.batch_size = max(
+                int(self.batch_size * self.backoff_factor), self.min_batch_size
+            )
+
+    def get_performance_metrics(self) -> Dict[str, Any]:
+        r"""Get current performance metrics.
+
+        Returns:
+            Dict containing performance metrics including:
+            - total_processed: Total number of batches processed
+            - error_rate: Percentage of failed batches
+            - avg_processing_time: Average time per batch
+            - current_batch_size: Current batch size
+            - current_workers: Current number of workers
+            - current_cpu: Current CPU usage percentage
+            - current_memory: Current memory usage percentage
+        """
+        metrics = {
+            "total_processed": self.total_processed,
+            "error_rate": (self.total_errors / max(1, self.total_processed))
+            * 100,
+            "avg_processing_time": sum(self.processing_times)
+            / max(1, len(self.processing_times)),
+            "current_batch_size": self.batch_size,
+            "current_workers": self.max_workers,
+            "current_cpu": self.current_cpu,
+            "current_memory": self.current_memory,
+        }
+        return metrics
 
 
 def download_github_subdirectory(
@@ -728,3 +953,88 @@ def generate_prompt_for_structured_output(
     {user_prompt}
     """
     return final_prompt
+
+
+def with_timeout(timeout=None):
+    r"""Decorator that adds timeout functionality to functions.
+
+    Executes functions with a specified timeout value. Returns a timeout
+    message if execution time is exceeded.
+
+    Args:
+        timeout (float, optional): The timeout duration in seconds. If None,
+            will try to get timeout from the instance's timeout attribute.
+            (default: :obj:`None`)
+
+    Example:
+        >>> @with_timeout(5)
+        ... def my_function():
+        ...     return "Success"
+        >>> my_function()
+
+        >>> class MyClass:
+        ...     timeout = 5
+        ...     @with_timeout()
+        ...     def my_method(self):
+        ...         return "Success"
+    """
+
+    def decorator(func):
+        if inspect.iscoroutinefunction(func):
+
+            @functools.wraps(func)
+            async def async_wrapper(*args, **kwargs):
+                eff_timeout = timeout
+                if eff_timeout is None and args:
+                    eff_timeout = getattr(args[0], 'timeout', None)
+
+                if eff_timeout is None:
+                    return await func(*args, **kwargs)
+
+                return await asyncio.wait_for(
+                    func(*args, **kwargs), timeout=eff_timeout
+                )
+
+            return async_wrapper
+        else:
+
+            @functools.wraps(func)
+            def wrapper(*args, **kwargs):
+                # Determine the effective timeout value
+                effective_timeout = timeout
+                if effective_timeout is None and args:
+                    effective_timeout = getattr(args[0], 'timeout', None)
+
+                # If no timeout value is provided, execute function normally
+                if effective_timeout is None:
+                    return func(*args, **kwargs)
+
+                # Container to hold the result of the function call
+                result_container = []
+
+                def target():
+                    result_container.append(func(*args, **kwargs))
+
+                # Start the function in a new thread
+                thread = threading.Thread(target=target)
+                thread.start()
+                thread.join(effective_timeout)
+
+                # Check if the thread is still alive after the timeout
+                if thread.is_alive():
+                    return (
+                        f"Function `{func.__name__}` execution timed out, "
+                        f"exceeded {effective_timeout} seconds."
+                    )
+                else:
+                    return result_container[0]
+
+        return wrapper
+
+    # Handle both @with_timeout and @with_timeout() usage
+    if callable(timeout):
+        # If timeout is passed as a function, apply it to the decorator
+        func, timeout = timeout, None
+        return decorator(func)
+
+    return decorator
